import { Logger, AccessoryConfig } from 'homebridge';
/**
 * This interface defines a sauna characteristic
 */
export interface SaunaCharacteristic {
    /**
     * the unique ID
     */
    readonly id: number;
    /**
     * the human readable name
     */
    readonly name: string;
}
/**
 * This class is the API via websocket to the Pronet web gateway.
 */
export declare class SentiotecAPI {
    /**
     * the logger that should be used
     */
    private log;
    /**
     * the map of cached values
     */
    private cachedValues?;
    /**
     * indicates that a data refresh is currently in progress
     */
    private dataUpdateInProgress;
    /**
     * indicates if a/the Sauna is actually connected to the pronet unit
     */
    connected: boolean;
    /**
     * the websocket to be used
     */
    private websocket?;
    /**
     * the timeout for the websocket
     */
    private webSocketTimeout?;
    /**
     * the sauna target IP
     */
    private ip;
    /**
     * the sauna password
     */
    private password;
    /**
     * the sauna serial number
     */
    private serial;
    /**
     * the ID of the sauna
     */
    private saunaID;
    /**
     * indicates a first start (for the request of the characteristics)
     */
    private firstStart;
    /**
     * the ID and name for the target temperature
     */
    TARGET_TEMPERATURE: SaunaCharacteristic;
    /**
     * the ID and name for the current temperature
     */
    readonly CURRENT_TEMPERATURE: SaunaCharacteristic;
    /**
     * the ID and name for the firmware
     */
    readonly FIRMWARE: SaunaCharacteristic;
    /**
     * the ID and name for the on/off switch
     */
    readonly ACTIVE: SaunaCharacteristic;
    /**
     * the constructor
     * @param log the logger to be used
     * @param config the service configuration
     */
    constructor(log: Logger, config: AccessoryConfig);
    /**
     * This function creates a new websocket and authenticates the user based on the information given in the constructor
     * @returns a Promise to handle the connection and authentication process
     */
    private connect;
    /**
     * This function closes the websocket and does the cleanup.
     */
    private close;
    /**
     * This function returns a characteristic from the sauna (either cached or directly)
     * @param characteristicID the ID of the characteristic
     */
    getCharacteristic(saunaCharacteristic: SaunaCharacteristic): Promise<string>;
    /**
     * This function sets a characteristic on the sauna.
     * @param characteristicID the ID of the characteristic
     * @param value the corresponding value (currently only active and temperature - both numbers - can be set)
     * @returns a Promise for the execution
     */
    setCharacterstic(saunaCharacteristic: SaunaCharacteristic, value: number): Promise<undefined>;
}
//# sourceMappingURL=websocket.d.ts.map